/*
 * Project name:
     DISPLAY_BT (Simple demo for the Bluetooth serial adapter board)
 * Copyright:
     (c) www.tigal.com, 2007.
 * Description:
     Demonstration of an DISPLAY remote control application
     using the Bluetooth serial adapter board.
 * Test configuration:
     MCU:             PIC16F877A
     Dev.Board:       EasyPIC3
     Oscillator:      HS, 08.0000 MHz
     Ext. Modules:    LCD 2x16
     SW:              mikroC v6.0
 * NOTES:
     None.
*/

char text; // buffer for the received text

unsigned short v, por1, por2, por3;

void BT_SetCableReplacement();

unsigned short mask(unsigned short);

void interrupt() {
  if (v==0) {
    PORTD = por1;      //  send mask for digit 3 to portb
    PORTA = 1;         //  turn on 1st 7 seg., turn off all the others
    v = 1;
  } else if (v==1){
    PORTD = por2;      //  send mask for digit 8 to portb
    PORTA = 2;         //  turn on 2nd 7 seg., turn off all the others
    v = 2;
  } else {
    PORTD = por3;      //  send mask for digit 8 to portb
    PORTA = 4;         //  turn on 2nd 7 seg., turn off all the others
    v = 0;
  }
  TMR0 = 0;            //  clear TMRO
  INTCON = 0x20;       //  clear TMR0IF and set TMR0IE
}

void main() {
  USART_init(9600);
  BT_SetCableReplacement(); // disable all BT notifications

  OPTION_REG  = 0x80;   // pull up resistors
  PORTA       =   0;    // clear porta (make sure both displays are off)
  TRISA       =   0;    // designate porta pins as output
  PORTD       =   0;    // clear portb (make sure LEDs are off)
  TRISD       =   0;    // designate portb pins as input
  TMR0        =   0;    // clear TMRO
  por1        = mask(0);
  por2        = mask(0);
  por3        = mask(0);
  INTCON      = 0xA0;   // enable T0IE

  while (1) {
    if (USART_Data_Ready()) {
      text = USART_Read();
      por1 = mask(text/100);
      por2 = mask((text%100)/10);
      por3 = mask(text%10);
      USART_Write(text);
    }
  }
}

void BT_SetCableReplacement()
{
  USART_Write(0x02);
  USART_Write(0x52);
  USART_Write(0x4E);
  USART_Write(0x01);
  USART_Write(0x00);
  USART_Write(0xA1);
  USART_Write(0x03);
  USART_Write(0x03);
}

//-------------- Returns mask for common cathode 7-seg. display
unsigned short mask(unsigned short num) {
  switch (num) {
    case 0 : return 0x3F;
    case 1 : return 0x06;
    case 2 : return 0x5B;
    case 3 : return 0x4F;
    case 4 : return 0x66;
    case 5 : return 0x6D;
    case 6 : return 0x7D;
    case 7 : return 0x07;
    case 8 : return 0x7F;
    case 9 : return 0x6F;
  } //case end
}



